import { Modal, View, Text, StyleSheet, Image } from "react-native";
import WhiteButton from "../buttons/WhiteButton";

interface Props {
    showModal: boolean;
    onClosePressed: () => void;
    roomId?: string;
}

export default function ModalInvitePlayer({showModal, onClosePressed, roomId}: Props) {
    return (
        <Modal visible={showModal} animationType="slide" transparent={true}>
            <View style={styles.centeredView}>
                <View style={styles.modalView}>
                    <Text style={styles.title}>JOIN</Text>
                    <Image source={require('../../assets/favicon.png')}/>
                    <Text style={styles.or}>OR</Text>
                    <Text style={styles.link}>Room ID: {roomId}</Text>
                    <View style={styles.buttonGroup}>
                        <WhiteButton text="CLOSE" onPress={onClosePressed} isDisabled={false}/>
                    </View>
                </View>
            </View>
        </Modal>
    );
}

const styles = StyleSheet.create({
    centeredView: {
        flex: 1,
        justifyContent: 'center',
        alignItems: 'center',
        backgroundColor: 'rgba(0, 0, 0, 0.5)'
    },
    modalView: {
        display: 'flex',
        justifyContent: 'space-between',
        height: '50%',
        width: '90%',
        margin: '10%',
        padding: '5%',
        backgroundColor: 'white',
        borderRadius: 20,
        alignItems: 'center',
        shadowColor: '#000',
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.25,
        shadowRadius: 4,
        elevation: 5,
    },
    buttonGroup: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        width: '100%',
    },
    title: {
        fontSize: 40,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
        alignSelf: "center",
        textAlign: 'center',
    },
    or: {
        fontSize: 32,
    },
    link: {
        color: '#0000EE',
        fontSize: 22,
        fontWeight: "bold",
    }
});