import React from "react";
import { TextInput, View, StyleSheet, Text } from "react-native";

interface Props {
    title?: string;
    setText: (text: string) => void;
    noTitle?: boolean;
    placeholder?: string;
    numeric?: boolean;
    defaultValue?: string;
    isSecure?: boolean;
}

export default function InputPlayQuiz({ title, setText, noTitle, placeholder, numeric, defaultValue, isSecure=false }: Props) {
    return (
        <View style={styles.container}>
            {!noTitle && title && <Text style={styles.title}>{title}</Text>}
            <TextInput
                style={styles.input}
                placeholder={placeholder || ""}
                placeholderTextColor="#bebebe"
                keyboardType={numeric ? "numeric" : "default"} // Clavier conditionnel
                onChangeText={(text) => {
                    setText(text);
                }}
                defaultValue={defaultValue}
                secureTextEntry={isSecure}
            />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: "flex",
        flexDirection: "column",
        alignItems: "flex-start",
        width: "100%",
    },
    input: {
        width: "100%",
        height: 70,
        backgroundColor: "white",
        borderColor: "#2ec7ff",
        borderWidth: 3,
        borderRadius: 8,
        paddingLeft: 10,
        elevation: 5,
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 4 },
        shadowOpacity: 0.25,
        shadowRadius: 3.84,
    },
    title: {
        fontSize: 20,
        fontWeight: "bold",
        marginBottom: 5,
        color: "#333",
        textAlign: "left",
        width: "100%",
    },
});
