import { View, StyleSheet, Text } from "react-native";
import { SelectList } from "react-native-dropdown-select-list";
import React from "react";

interface Props {
    data: any,
    setSelected: (val: string) => void,
    title: string,

}

export default function SelectListBoxString({data, setSelected, title} : Props) {

    return (
        <View style={styles.container}>
            <View style={styles.dropdownContainer}>
                <Text style={styles.title}>{title}</Text>
                <SelectList
                    setSelected={(val: any) => setSelected(val)}
                    data={data}
                    save="value"
                    dropdownStyles={styles.dropdownStyles} // Applique un style personnalisé au menu déroulant
                    boxStyles={styles.boxStyles} // Applique un style personnalisé au champ de saisie
                    inputStyles={styles.inputStyles}
                />
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        alignItems: "center",
        width: '100%',
    },
    dropdownContainer: {
        width: "100%",
    },
    title: {
        fontSize: 20,
        fontWeight: "bold", // Met le texte en gras
        marginBottom: 5, // Ajoute un espace entre le titre et la boîte déroulante
        color: "#333", // Couleur du texte
        textAlign: "left", // Aligne le texte à gauche
    },
    dropdownStyles: {
        position: "absolute", // Rend le dropdown flottant
        width: "100%", // Ajustez la largeur du dropdown
        top: 40, // Ajustez la position verticale
        zIndex: 2, // Assure que le menu apparaît au-dessus
        backgroundColor: "white", // Ajoute une couleur de fond
        borderColor: "black", // Optionnel : bordure de couleur
        borderWidth: 1, // Optionnel : épaisseur de la bordure
        borderRadius: 8, // Optionnel : coins arrondis
    },
    boxStyles: {
        backgroundColor: "white",
        borderColor: "#bebebe",
        borderWidth: 2,
        borderRadius: 8,
        height: 70, // Hauteur augmentée
        alignItems: "center",
        elevation: 5,
        // Ombre pour iOS
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 4 }, // Décalage de l'ombre en bas
        shadowOpacity: 0.25, // Opacité de l'ombre
        shadowRadius: 3.84, // Flou de l'ombre
    },
    inputStyles: {
        fontSize: 18, // Taille du texte augmentée
        color: "black", // Couleur du texte
    },
});
