import React from "react";
import {
    Modal,
    View,
    Text,
    StyleSheet,
    TouchableOpacity,
    TouchableWithoutFeedback,
} from "react-native";
import Icon from "react-native-vector-icons/MaterialIcons";
import BlueButton from "../buttons/BlueButton"; // Pour l'icône de fermeture

interface Props {
    visible: boolean;
    onClose: () => void;
    onConfirm: () => void;
}

export default function ConfirmModal({ visible, onClose, onConfirm }: Props) {
    return (
        <Modal
            animationType="slide"
            transparent={true}
            visible={visible}
            onRequestClose={onClose} // Ferme la modal en cas d'interaction système
        >
            <TouchableWithoutFeedback onPress={onClose}>
                <View/>
            </TouchableWithoutFeedback>
            <View style={styles.modalContainer}>
                <TouchableOpacity style={styles.closeButton} onPress={onClose}>
                    <Icon name="close" size={24} color="#000" />
                </TouchableOpacity>
                <Text style={styles.title}>WOULD YOU LIKE TO RETURN TO THE MENU ?</Text>
                <View style={styles.separator} />
                <View style={styles.buttonContainer}>
                    <BlueButton text={"CONFIRM"} onPress={onConfirm} isDisabled={false}/>
                </View>
            </View>
        </Modal>
    );
}

const styles = StyleSheet.create({
    overlay: {
        flex: 1,
        backgroundColor: "rgba(0, 0, 0, 0.5)",
    },
    modalContainer: {
        position: "absolute",
        top: "40%",
        left: "10%",
        right: "10%",
        backgroundColor: "white",
        borderRadius: 10,
        padding: 20,
        alignItems: "center",
        elevation: 5,
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.25,
        shadowRadius: 4,
    },
    closeButton: {
        position: "absolute",
        top: 10,
        right: 10,
        zIndex: 1,
    },
    title: {
        fontSize: 16,
        fontWeight: "bold",
        color: "#000",
        textAlign: "center",
        marginVertical: 20,
    },
    separator: {
        width: "100%",
        height: 2,
        backgroundColor: "#bebebe",
        marginVertical: 10,
    },
    confirmButton: {
        backgroundColor: "#1FA9FF",
        borderRadius: 8,
        paddingVertical: 10,
        paddingHorizontal: 20,
        alignItems: "center",
        justifyContent: "center",
        marginTop: 10,
        width: "80%",
    },
    confirmButtonText: {
        color: "#fff",
        fontSize: 16,
        fontWeight: "bold",
    },
    buttonContainer: {
        flexDirection: "row",
        justifyContent: "space-between",
        alignItems: "center",
        width: "80%",
        marginTop: 10,
    },
});
