import React from "react";
import { FlatList, View, Text, StyleSheet, Image } from "react-native";
import {User} from "../../../models/User";
import {UserEndQuiz} from "../../../models/UserEndQuiz";

interface Props {
    users: UserEndQuiz[];
    maxScore: number;
}

export default function EndQuizListPlayer({ users, maxScore }: Props) {

    const renderUser = ({ item, index }: { item: UserEndQuiz; index: number }) => (
        <View style={[styles.userContainer, index === 0 && styles.firstPlace]}>
            <Image
                source={require("../../../assets/ProfilBaseImage.png")} // Replace with actual profile picture if available
                style={styles.avatar}
            />
            <View style={styles.infoContainer}>
                <Text style={[styles.username, index === 0 && styles.firstPlaceText]}>
                    {item.username.toUpperCase()}
                </Text>
                <Text style={styles.score}>
                    {item.score}/{maxScore} {/* Adjust score logic as needed */}
                </Text>
            </View>
        </View>
    );

    return (
        <View style={styles.container}>
            <FlatList
                data={users}
                renderItem={renderUser}
                keyExtractor={(item) => item.id.toString()}
                showsVerticalScrollIndicator={false}
            />
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        width: "100%",
        height: "35%",
        padding: 20,
        backgroundColor: "#fff",
        borderRadius: 20,
    },
    userContainer: {
        flexDirection: "row",
        alignItems: "center",
        backgroundColor: "#f9f9f9",
        borderRadius: 10,
        padding: 15,
        marginBottom: 10,
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.1,
        shadowRadius: 3,
        elevation: 2,
    },
    firstPlace: {
        // backgroundColor: "#ffe700",
        // shadowColor: "#ff9900",
        // shadowOpacity: 0.3,
    },
    avatar: {
        width: 40,
        height: 40,
        borderRadius: 25,
        marginRight: 15,
    },
    infoContainer: {
        flex: 1,
    },
    username: {
        fontSize: 18,
        fontWeight: "bold",
        color: "#333",
    },
    firstPlaceText: {
        // color: "#ff9900",
    },
    score: {
        fontSize: 16,
        color: "#666",
    },
});
