import React, { useEffect, useState } from 'react';
import { View, Button, Text } from 'react-native';
import { Audio } from 'expo-av';

interface Props {
  base64Audio: string;
  forceEnd: boolean;
}

export default function Base64AudioPlayer({ base64Audio, forceEnd }: Props) {
  const [sound, setSound] = useState<Audio.Sound | null>(null);
  const [isPlaying, setIsPlaying] = useState(false);

  const playAudio = async () => {
    try {
      const { sound } = await Audio.Sound.createAsync(
        { uri: `${base64Audio}` }
      );
      setSound(sound);

      await sound.playAsync();
      setIsPlaying(true);

      sound.setOnPlaybackStatusUpdate((status) => {
        if (status.isLoaded && !status.isBuffering && status.didJustFinish) {
          setIsPlaying(false);
        }
      });
    } catch (error) {
      console.error('Erreur lors de la lecture de l\'audio :', error);
    }
  };

  const stopAudio = async () => {
    if (sound) {
      await sound.stopAsync();
      setIsPlaying(false);
    }
  };

  useEffect(() => {
    stopAudio();
  }, [forceEnd]);
  
  return (
    <View style={{ padding: 20 }}>
      <Text style={{ marginBottom: 10 }}>Appuyer pour jouer l'audio</Text>
      <Button title={isPlaying ? 'Arrêter l\'audio' : 'Jouer l\'audio'} onPress={isPlaying ? stopAudio : playAudio} />
    </View>
  );
}