import { View, Text, StyleSheet, TouchableOpacity, GestureResponderEvent } from "react-native";

interface Props {
    onPress: ((event: GestureResponderEvent) => void) | undefined;
    text: string;
    buttonStyle?: any;
    isDisabled: boolean;
}

export default function BlueButton({ onPress, text, buttonStyle, isDisabled }: Props) {
    return (
        <TouchableOpacity
            style={[
                styles.container,
                isDisabled ? styles.disabledContainer : styles.enabledContainer,
                buttonStyle,
            ]}
            onPress={onPress}
            disabled={isDisabled}
        >
            <Text style={[styles.text, isDisabled && styles.disabledText]}>{text}</Text>
        </TouchableOpacity>
    );
}

const styles = StyleSheet.create({
    container: {
        width: "100%",
        height: 70,
        alignItems: "center",
        justifyContent: "center",
        borderRadius: 10,
    },
    enabledContainer: {
        backgroundColor: "#2b73fe", // Couleur bleue par défaut
    },
    disabledContainer: {
        backgroundColor: "#b0b0b0", // Gris désactivé
    },
    text: {
        fontSize: 28,
        color: "white",
        fontWeight: "bold",
    },
    disabledText: {
        color: "#d0d0d0", // Texte grisé pour un bouton désactivé
    },
});
