import {View, Text} from "react-native";
import TemplateQuizList from "../../templates/TemplateQuizList";
import {NavigationProp} from "@react-navigation/native";
import {useEffect, useState} from "react";
import {useQuizService} from "../../services/QuizService";
import HttpError from "../../services/HttpError";
import {useInfiniteQuery} from "@tanstack/react-query";
import { Quiz } from "../../models/Quiz";

interface Props {
    navigation: NavigationProp<any>
}
export default function Community({navigation}: Props) {
    const  {getCommunityQuiz} = useQuizService();
    const [input, setInput] = useState<string>("")
    const [loading, setLoading] = useState<boolean>(false)

    const fetchCommunityQuizzes = async ({pageParam = 1}) => {
        const quizzes = await getCommunityQuiz(pageParam,7);
        if (HttpError.isHttpError(quizzes)) {
            console.error("Error while fetching community quizzes:", quizzes);
            return [];
        }
        return quizzes;
    }

    const onQuizPressed = (quiz: Quiz) => {
        navigation.navigate("InformationsOfQuiz", { quiz: quiz });
    };


    const {
        data,
        fetchNextPage,
    } = useInfiniteQuery({
        queryKey: ["communityQuizzes"],
        queryFn: fetchCommunityQuizzes,
        initialPageParam: 0,
        getNextPageParam: (lastPage, allPages) => {
            // Si la dernière page a moins de 7 quizzes, il n'y a plus de page suivante
            if (lastPage.length < 7) return undefined;

            // On augmente skip de 7 pour la prochaine requête
            return allPages.length * 7;
        }});

    return (
        <TemplateQuizList title={"Community"} setTextInInput={setInput} quizList={data?.pages.flat() ?? []} navigation={navigation} buttonGoBack={false} isLoadingData={loading} nextPage={fetchNextPage} onQuizPressed={onQuizPressed}/>
    );
}