import React from "react";
import {View, Text, StyleSheet, TouchableOpacity, Dimensions} from "react-native";
import TemplateMenu from "../../../templates/TemplateMenu";
import {NavigationProp, RouteProp} from "@react-navigation/native";
import {Quiz} from "../../../models/Quiz";
import { useQuizService } from "../../../services/QuizService";

type RoutePropsType = {
    InformationsOfQuiz: {
        quiz: Quiz;
    };
};
interface Props {
    navigation: NavigationProp<any>;
    route: RouteProp<RoutePropsType, "InformationsOfQuiz">;
}
const { width, height } = Dimensions.get('window');

export default function InformationsOfQuiz({ navigation, route }: Props) {
    const { quiz } = route.params;
    const { createRun } = useQuizService();

    const onPlay = async () => {
        const quizId = quiz.id.toString();
        const runId = await createRun(quizId);
        navigation.navigate('PlayingQuiz', { runId: runId, quizId: quizId });
    }

    const QuizStatistic = ({ label, value }: { label: string, value: string }) => (
        <View style={styles.statItem}>
            <Text style={styles.statLabel}>{label}</Text>
            <Text style={styles.statValue}>{value || "Loading..."}</Text>
        </View>
    );

    return (
        <TemplateMenu navigation={navigation} headerNavigation={true} buttonGoBack={true}>
            <View style={styles.container}>
                <Text style={styles.quizTitle}>{quiz.name}</Text>

                <View style={styles.infoCard}>
                    <View style={styles.statsContainer}>
                        {/*<QuizStatistic*/}
                        {/*    label="Current Score"*/}
                        {/*    value={quiz.score ? quiz.score.toString() : "Loading..."}*/}
                        {/*/>*/}
                        {/*<QuizStatistic*/}
                        {/*    label="Progress"*/}
                        {/*    value={`${quiz.questionIndex}/${quiz.questionCount}`}*/}
                        {/*/>*/}
                        <QuizStatistic
                            label="Difficulty"
                            value={quiz.difficulty.name}
                        />
                    </View>
                    <View style={styles.descriptionContainer}>
                        <Text style={styles.descriptionLabel}>Description</Text>
                        <Text style={styles.descriptionText}>
                            {quiz.description}
                        </Text>
                    </View>
                </View>

                {/*<View style={styles.aboutContainer}>*/}
                {/*    <Text style={styles.aboutTitle}>About this quiz :</Text>*/}
                {/*    <Text style={styles.aboutDetails}>{quiz.questionCount} questions, {quiz.difficulty.name}</Text>*/}
                {/*    <Text style={styles.aboutDetails}>By : {quiz.authorId && "Unknown"}</Text>*/}
                {/*</View>*/}

                <TouchableOpacity style={styles.playButton} onPress={onPlay}>
                    <Text style={styles.playButtonText}>PLAY</Text>
                </TouchableOpacity>
            </View>
        </TemplateMenu>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingHorizontal: 20,
        paddingVertical: 20,
        justifyContent: "flex-start",
    },
    descriptionContainer: {
        marginTop: 8,
    },
    descriptionLabel: {
        fontSize: 16,
        fontWeight: "600",
        color: "#666",
        marginBottom: 8,
    },
    descriptionText: {
        fontSize: 15,
        color: "#4a4a4a",
        lineHeight: 22,
    },
    infoCard: {
        height: '65%',
        backgroundColor: "white",
        borderRadius: width * 0.04,
        paddingHorizontal: '5%',
        shadowColor: "#000",
        shadowOffset: { width: 0, height: width * 0.01 },
        shadowOpacity: 0.1,
        shadowRadius: width * 0.03,
        elevation: 5,
    },
    statsContainer: {
        height: '15%',
        justifyContent: 'space-around',
    },
    quizTitle: {
        fontSize: 24,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
    },
    quizDescription: {
        fontSize: 16,
        color: "#555",
        marginBottom: 20,
        height: "15%",
    },
    aboutContainer: {
        height: "50%",
        backgroundColor: "white",
        borderRadius: 10,
        padding: 15,
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.2,
        shadowRadius: 3,
        elevation: 5,
    },
    aboutTitle: {
        fontSize: 18,
        fontWeight: "bold",
        marginBottom: 10,
        color: "#000",
    },
    statItem: {
        flexDirection: 'row',
        justifyContent: 'space-between',
        alignItems: 'center',
        paddingVertical: '3%',
        borderBottomWidth: 1,
        borderBottomColor: '#f0f0f0',
    },
    statLabel: {
        fontSize: width * 0.04,
        color: "#666",
        fontWeight: "500",
    },
    statValue: {
        fontSize: 16,
        color: "#2d2d2d",
        fontWeight: "600",
    },
    aboutDetails: {
        fontSize: 16,
        color: "#555",
        marginBottom: 10,
    },
    playButton: {
        backgroundColor: "#007BFF",
        paddingVertical: 15,
        borderRadius: 10,
        alignItems: "center",
        justifyContent: "center",
        marginTop: 20,
    },
    playButtonText: {
        fontSize: 18,
        fontWeight: "bold",
        color: "white",
    },
});
