import { View, StyleSheet, Image, Modal, TextInput } from "react-native";
import DefaultButton from "../../components/buttons/DefaultButton";
import {useTranslation} from "react-i18next";
import { useState } from "react";
import { TextsStyles } from "../../styles/TextsStyles";
import MenuButton from "../../components/buttons/MenuButton";
import {NavigationProp} from "@react-navigation/native";
import {useQuizService} from "../../services/QuizService";
import HttpError from "../../services/HttpError";

interface Props {
    navigation: NavigationProp<any>;
}

/**
 * HomeChild : Enfant de l'écran Home, il contient le menu principal
 * @param navigation - navigation
 */
export default function HomeChild({navigation}: Props) {
    const [modalVisible, setModalVisible] = useState(false);
    const {t} = useTranslation();
    const {getRandomQuiz} = useQuizService();

    const handleButtonQuickGamePressed = async () => {
        const quizData = await getRandomQuiz()
        if (quizData instanceof HttpError) {
            return;
        }
        navigation.reset({
            index: 0,
            routes: [
                {
                    name: "PlayingQuiz",
                    params: {runId: quizData.id, quizId: quizData.quizId},
                },
            ]

        });
    }
    const handleButtonMyQuizzesPressed = () => {
        navigation.navigate("MyQuizzes");
        // navigation.navigate("PlayingQuiz", {runId: "1", quizId: "1"});
    }

    const handleButtonGeneratePressed = () => {
        navigation.navigate("PlayQuiz");
    }

    return (
        <View style={styles.containerGlobal}>
            <View style={styles.imageContainer}>
                <Image source={require('../../assets/TitleApp.png')} style={styles.image} />
            </View>
            <View style={styles.buttonContainer}>
                <MenuButton text={"QUICK GAME"} handleButtonPressed={handleButtonQuickGamePressed}/>
                <MenuButton text={"PLAY"} handleButtonPressed={handleButtonGeneratePressed}/>
                <MenuButton text={"MY QUIZZES"} handleButtonPressed={handleButtonMyQuizzesPressed}/>
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    containerGlobal: {
        display: 'flex',
        width: '100%',
        height: '100%',
        justifyContent: 'flex-start',
        alignItems: 'center',
    },
    image: {
    },
    button: {
        borderRadius: 40,
        height: '35%',
        marginTop: '5%'
    },
    imageContainer: {
        display: 'flex',
        alignItems: 'center',
        marginTop: '15%',
        marginBottom: '35%',
    },
    buttonContainer: {
        width: '100%',
        display: 'flex',
        flexDirection: 'column',
        paddingLeft: '8%',
        gap: '9%',
    }
});