import {NavigationProp} from "@react-navigation/native";
import React, {useEffect, useState} from "react";
import TemplateRunList from "../../../templates/TemplateRunList";
import {useQuizService} from "../../../services/QuizService";
import HttpError from "../../../services/HttpError";
import {AllRunsResponse} from "../../../models/Response/AllRunsResponse";
import {RunsInformationsAllRuns} from "../../../models/RunsInformationsAllRuns";

interface Props {
    navigation: NavigationProp<any>
}
export default function MyQuizzes({navigation}: Props) {
    const [runList, setRunList] = useState<AllRunsResponse | undefined>(undefined)
    const [input, setInput] = useState<string>("")
    const {getAllRuns} = useQuizService();

    const getRuns = async () => {
        const runs = await getAllRuns();
        if(HttpError.isHttpError(runs)) {
            return
        }
        setRunList(runs);
    }

    useEffect(() => {
        getRuns();
    },[]);

    const onQuizPressed = (runInfo: RunsInformationsAllRuns) => {
        navigation.navigate("InformationsOfRuns", { runInformations: runInfo });
    };

    return (
        <TemplateRunList title={"My quizzes"} setTextInInput={setInput} runList={runList?.runs} navigation={navigation} buttonGoBack={true} isLoadingData={false} onRunPressed={onQuizPressed}/>
    );
}