import ComboBox from "../../../../components/comboBox/ComboBox";
import DefaultButton from "../../../../components/buttons/DefaultButton";
import {StyleSheet, View} from "react-native";
import {useState} from "react";
import {useTranslation} from "react-i18next";
import {useQuizService} from "../../../../services/QuizService";
import {EDifficulty} from "../../../../models/EDifficulty";
import {getIdOfCategory} from "../../../../helper/QuizHelper";

const optionsDifficulty = [ 'easy', 'medium', 'hard'];
const optionsQuestions = ['1', '50'];
const optionsTheme = [
    "General Knowledge",
    "Entertainment: Books",
    "Entertainment: Film",
    "Entertainment: Music",
    "Entertainment: Musicals & Theatres",
    "Entertainment: Television",
    "Entertainment: Video Games",
    "Entertainment: Board Games",
    "Science & Nature",
    "Science: Computers",
    "Science: Mathematics",
    "Mythology",
    "Sports",
    "Geography"]
interface Props {
    navigation: any;
}

export default function GenerateQuizBody({navigation}:Props) {

    const [isModalVisible, setIsModalVisible] = useState(false);
    const [difficulty, setDifficulty] = useState('easy');
    const [nbQuestions, setNbQuestions] = useState('1');
    const [theme, setTheme] = useState<string>('General Knowledge');
    const {t} = useTranslation();
    const {generateQuiz} = useQuizService();

    const handleAddQuizPressed = async () => {
        const quizGenerated = await generateQuiz(parseInt(nbQuestions), getIdOfCategory(theme), difficulty);
        navigation.reset({
            index: 0,
            routes: [
                {
                    name: "PlayingQuiz",
                    params: {quizRecovered: quizGenerated},
                },
            ]
        });
    };

    return (
        <View style={styles.container}>
            <View style={styles.comboBoxContainer}>
                <ComboBox title={t("app.screens.creationQuiz.difficulty")} options={optionsDifficulty} selectOption={setDifficulty} type={0}/>
                <ComboBox title={t("app.screens.creationQuiz.nbQuestions")} options={optionsQuestions} selectOption={setNbQuestions} type={1}/>
                <ComboBox title={t("app.screens.creationQuiz.theme")} options={optionsTheme} selectOption={setTheme} type={0}/>
            </View>
            <View style={styles.buttonContainer}>
                <DefaultButton text={t("app.screens.creationQuiz.addQuiz")} handleButtonPressed={handleAddQuizPressed} buttonStyle={styles.buttonStyle}/>
            </View>
        </View>

    )
}

const styles = StyleSheet.create({
    container: {
        padding: 10,
        display: "flex",
        flexDirection: "column",
        justifyContent: "center",
        alignItems: "center",
        height: "90%",
        width: "100%",
    },
    comboBoxContainer: {
        display: "flex",
        flexDirection: "column",
        alignItems: "center",
        width: "80%",
        height: "100%",
    },
    buttonContainer: {
        display: "flex",
        justifyContent: "center",
        alignItems: "center",
    },
    buttonStyle: {
        backgroundColor: "#7988D7",
    },
});
