import {NavigationProp, RouteProp} from "@react-navigation/native";
import {useQuizService} from "../../../../services/QuizService";
import React, {useEffect, useState} from "react";
import {QuizInformations} from "../../../../models/QuizInformations";
import {Question} from "../../../../models/Question";
import TemplateDuo from "../../../../templates/TemplateDuo";
import HttpError from "../../../../services/HttpError";
import PlayingQuizMultiModeHeader from "./PlayingQuizMultiModeHeader";
import PlayingQuizMultiModeBody from "./PlayingQuizMultiModeBody";
import {Socket} from "socket.io-client";
import {QuestionResponse} from "../../../../models/Response/QuestionResponse";
import {RunInformations} from "../../../../models/RunInformations";
import EventSource from "react-native-sse";
import {CustomEventType} from "../../../../models/CustomEventType";
import {AnswerSSEResponse} from "../../../../models/Response/AnswerSSEResponse";
import {useMultiService} from "../../../../services/MultiService";
import {UserEndQuiz} from "../../../../models/UserEndQuiz";
import {shuffleAnswersOfQuiz} from "../../../../helper/QuizHelper";


type RoutePropsType = {
    PlayingQuizMultiMode: {
        runId: string;
        questionCount: number;
        es: EventSource<CustomEventType>;
        roomId: string;
        isHost: boolean;
    };
};

enum QuizState {
    ANSWERING= "Answering",
    LOADING= "Loading",
    SHOWING_RESULTS= "ShowingResults",
}

interface Props {
    route: RouteProp<RoutePropsType, "PlayingQuizMultiMode">;
    navigation: NavigationProp<any>;
}

export default function PlayingQuizMultiMode({route, navigation}:Props) {
    const {runId, es, roomId,questionCount, isHost} = route.params;

    const {getQuizInformations, getRunsInfo} = useQuizService();
    const [quizState, setQuizState] = useState(QuizState.ANSWERING);
    const [quizInformations, setQuizInformations] = useState<QuizInformations | undefined>(undefined);
    const [runInformations, setRunInformations] = useState<RunInformations>();
    const [actualQuestion, setActualQuestion] = useState<Question | undefined>(undefined);
    const [score, setScore] = useState(0);
    const {nextQuestion} = useMultiService();

    const initES = () => {
        es.addEventListener("nextQuestion", (event) => {
            if (!event.data) return;
            const question: Question = JSON.parse(event.data);

            setActualQuestion(shuffleAnswersOfQuiz(question));
            setQuizState(QuizState.ANSWERING);
        });

        es.addEventListener("gameEnded", (event) => {
            if (!event.data) return;
            const users: UserEndQuiz[] = JSON.parse(event.data);
            navigation.navigate("EndQuizMulti", { users: users, questionCount: questionCount });
        });
    }
    const fetchRuns = async () => {
        if (runId === undefined) return;
        const runFetched = await getRunsInfo(runId);
        if (runFetched instanceof HttpError) {
            console.log("Error fetching runs info", runFetched);
            return;
        }
        const quizInformationsFetched = await getQuizInformations(runFetched.quizId);
        if (quizInformationsFetched instanceof HttpError) {
            console.log("Error fetching quiz info", quizInformationsFetched);
            return;
        }
        setQuizInformations(quizInformationsFetched);
        setRunInformations(runFetched);
    };

    useEffect(() => {
        initES();
        fetchRuns();
        nextQuestion();
    }, []);

    return (
        <TemplateDuo
            childrenHeader={<PlayingQuizMultiModeHeader quizInformations={quizInformations} runId={runId}
                                                        actualQuestion={actualQuestion} score={score}
                                                        navigation={navigation} questionCount={questionCount}></PlayingQuizMultiModeHeader>}
            childrenBody={<PlayingQuizMultiModeBody runId={runId} actualQuestion={actualQuestion} es={es}
                                                    fetchActualQuestion={() => {
                                                    }} roomId={roomId} isHost={isHost}
                                                    navigation={navigation}
                                                    quizState={quizState}
                                                    setScore={setScore}
                                                    setQuizState={setQuizState}>
            </PlayingQuizMultiModeBody>}
        />
    );
}
