import {QuizInformations} from "../../../../models/QuizInformations";
import {Question} from "../../../../models/Question";
import {NavigationProp} from "@react-navigation/native";
import {useTranslation} from "react-i18next";
import {useState} from "react";
import {View, Text, StyleSheet} from "react-native";
import GoHomeButton from "../../../../components/PlayingQuiz/GoHomeButton";
import {TextsStyles} from "../../../../styles/TextsStyles";
import ConfirmModal from "../../../../components/PlayingQuiz/ComfirmModal";
import {QuestionResponse} from "../../../../models/Response/QuestionResponse";

interface Props {
    quizInformations?: QuizInformations;
    runId?: string;
    actualQuestion?: Question;
    score: number;
    questionCount: number;
    navigation: NavigationProp<any>

}

export default function PlayingQuizMultiModeHeader({quizInformations, runId, actualQuestion, score, questionCount, navigation}: Props) {
    const [isConfirmModalVisible, setIsConfirmModalVisible] = useState(false);
    const {t} = useTranslation();


    const handleConfirmModalConfirm = () => {
        navigation.reset({
            index: 0,
            routes: [
                {
                    name: "TabNavigator",
                },
            ]
        });
    }

    return (
        <View style={styles.container}>
            <View style={styles.header}>
                <GoHomeButton navigation={navigation} onPress={setIsConfirmModalVisible}/>
                <Text style={styles.codeQuizText}>ID QUIZZ : {runId}</Text>
            </View>
            <View style={styles.questionAndScoreContainer}>
                <View style={styles.InformationsContainer}>
                    <Text style={TextsStyles.titleText}>{t("app.screens.question.question")}</Text>
                    <Text style={TextsStyles.titleText}>{actualQuestion ? actualQuestion.order + 1 :"?"}/{questionCount}</Text>
                </View>
                <View style={styles.InformationsContainer}>
                    <Text style={TextsStyles.titleText}>{t("app.screens.question.score")}</Text>
                    <Text style={TextsStyles.titleText}>{score}/{questionCount}</Text>
                </View>
            </View>
            <View style={styles.QuizQuestionContainer}>
                <Text style={TextsStyles.subtitleText}>{actualQuestion ? actualQuestion.text : "Loading..."}</Text>
            </View>
            <ConfirmModal visible={isConfirmModalVisible} onClose={()=>setIsConfirmModalVisible(false)} onConfirm={handleConfirmModalConfirm}/>

        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        marginHorizontal: '5%',
    },
    questionAndScoreContainer: {
        display: 'flex',
        flexDirection: 'row',
        justifyContent: 'space-around',
        alignItems: 'center',
        marginVertical: '2%',
    },
    InformationsContainer: {
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'center',
        alignItems: 'center',
        gap: '5%',
    },
    QuizNumContainer: {
    },
    QuizQuestionContainer: {
        marginVertical: "2.5%",
    },
    infoQuizContainer: {
        marginBottom: '5%',
    },
    codeQuizText: {
        fontSize: 18,
        color: '#000000',
    },
    header: {
        display: "flex",
        flexDirection: "row",
        justifyContent: "flex-start",
        gap: '5%',
    }
});