import {Image, StyleSheet, Text, View} from "react-native";
import {useTranslation} from "react-i18next";
import React, {useEffect, useState} from "react";
import MenuButton from "../../components/buttons/MenuButton";
import {NavigationProp} from "@react-navigation/native";
import HttpError from "../../services/HttpError";
import {useUserService} from "../../services/UserService";
import {UserConnectionState} from "../../models/User";
import LoadingIndicator from "../../components/loading/LoadingIndicator";
import Connection from "../Profil/Connection/Connection";

interface Props {
    navigation: NavigationProp<any>;
}


/**
 * HomeChild : Enfant de l'écran Home, il contient le menu principal
 * @param navigation - navigation
 */
export default function MultiplayerChild({navigation}: Props) {
    const [modalVisible, setModalVisible] = useState(false);
    const {t} = useTranslation();
    const [userConnectionState, setUserConnectionState] = useState(UserConnectionState.LOADING);
    const { getInformationsUser, logoutUser } = useUserService();

    const getUser = async () => {
        setUserConnectionState(UserConnectionState.LOADING);
        const user = await getInformationsUser();
        if(user instanceof HttpError){
            setUserConnectionState(UserConnectionState.NOT_CONNECTED);
            return;
        }
        setUserConnectionState(UserConnectionState.CONNECTED);
    }

    useEffect(() => {
        getUser();
    }, []);

    const handleButtonCommunityPressed = async () => {
        navigation.navigate("MultiplayerCommunity");
    }
    
    const handleOnlineQuizPressed = () => {
        navigation.navigate("OnlineQuiz");
    }

    const handleButtonOngoingQuizzesPressed = () => {
        navigation.navigate("OngoingQuizzes");
    }

    return (
        <View style={styles.containerGlobal}>
            {userConnectionState === UserConnectionState.LOADING && (
                <LoadingIndicator/>
            )}
            {userConnectionState === UserConnectionState.CONNECTED && (
                <>
                <View style={styles.imageContainer}>
                    <Image source={require('../../assets/TitleApp.png')} style={styles.image} />
                </View>
                <View style={styles.buttonContainer}>
                    <MenuButton text={"COMMUNITY"} handleButtonPressed={handleButtonCommunityPressed}/>
                    <MenuButton text={"PLAY AN ONLINE QUIZ"} handleButtonPressed={handleOnlineQuizPressed}/>
                </View>
            </>
            )}
            {userConnectionState === UserConnectionState.NOT_CONNECTED && (
                <Connection title={"Multiplayer"} navigation={navigation}/>
            )}
        </View>
    );
}

const styles = StyleSheet.create({
    containerGlobal: {
        display: 'flex',
        width: '100%',
        height: '100%',
        justifyContent: 'flex-start',
        alignItems: 'center',
    },
    image: {
    },
    title: {
        fontSize: 40,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
        alignSelf: "center", // Centre uniquement le titre
    },
    button: {
        borderRadius: 40,
        height: '35%',
        marginTop: '5%'
    },
    imageContainer: {
        display: 'flex',
        alignItems: 'center',
        marginTop: '15%',
        marginBottom: '25%',
    },
    buttonContainer: {
        width: '100%',
        display: 'flex',
        flexDirection: 'column',
        paddingLeft: '8%',
        gap: '9%',
    }
});