import React, { useState } from "react";
import { View, Text, StyleSheet, TouchableOpacity } from "react-native";
import TemplateMenu from "../../../../templates/TemplateMenu";
import {NavigationProp, RouteProp} from "@react-navigation/native";
import {Quiz} from "../../../../models/Quiz";
import ModalCreateLobby from "../../../../components/Multiplayer/ModalCreateLobby";

type RoutePropsType = {
    InformationsOfQuiz: {
        quiz: Quiz;
    };
};
interface Props {
    navigation: NavigationProp<any>;
    route: RouteProp<RoutePropsType, "InformationsOfQuiz">;
}

export default function MultiInformationsOfQuiz({ navigation, route }: Props) {
    const { quiz } = route.params;
    const [showModal, setShowModal] = useState<boolean>(false);

    const onCreateLobbyPressed = () => {
        setShowModal(true);
    };

    const onClosePressed = () => {
        setShowModal(false);
    };

    const onPlayPressed = async (nbPlayer: number) => {
        setShowModal(false);
        navigation.navigate("Lobby", {quizId: quiz.id, roomId: null, nbPlayer: nbPlayer, isHost: true, questionCount: quiz.questionCount});
    };

    return (
        <TemplateMenu navigation={navigation} headerNavigation={true} buttonGoBack={true}>
            <View style={styles.container}>
                <Text style={styles.quizTitle}>{quiz.name}</Text>
                <Text style={styles.quizDescription}>{quiz.description && "No Description"}</Text>
                

                <View style={styles.aboutContainer}>
                    <Text style={styles.aboutTitle}>About this quiz :</Text>
                    <Text style={styles.aboutDetails}>{quiz.questionCount} questions, {quiz.difficulty.name}</Text>
                    <Text style={styles.aboutDetails}>By : {quiz.authorId && "Unknown"}</Text>
                </View>

                <TouchableOpacity style={styles.playButton} onPress={onCreateLobbyPressed}>
                    <Text style={styles.playButtonText}>CREATE LOBBY</Text>
                </TouchableOpacity>
            </View>
            <ModalCreateLobby onClosePressed={onClosePressed} onPlayPressed={onPlayPressed} showModal={showModal}/>
        </TemplateMenu>

    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        paddingHorizontal: 20,
        paddingVertical: 20,
        justifyContent: "flex-start",
    },
    quizTitle: {
        fontSize: 24,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
    },
    quizDescription: {
        fontSize: 16,
        color: "#555",
        marginBottom: 20,
        height: "15%",
    },
    aboutContainer: {
        height: "50%",
        backgroundColor: "white",
        borderRadius: 10,
        padding: 15,
        shadowColor: "#000",
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.2,
        shadowRadius: 3,
        elevation: 5,
    },
    aboutTitle: {
        fontSize: 18,
        fontWeight: "bold",
        marginBottom: 10,
        color: "#000",
    },
    aboutDetails: {
        fontSize: 16,
        color: "#555",
        marginBottom: 10,
    },
    playButton: {
        backgroundColor: "#007BFF",
        paddingVertical: 15,
        borderRadius: 10,
        alignItems: "center",
        justifyContent: "center",
        marginTop: 20,
    },
    playButtonText: {
        fontSize: 18,
        fontWeight: "bold",
        color: "white",
    },
});
