import { StyleSheet, View, Text } from "react-native";
import React from "react";
import InputPlayQuiz from "../../../components/PlayQuiz/InputPlayQuiz";
import { useQuizService } from "../../../services/QuizService";
import HttpError from "../../../services/HttpError";
// import {getIdOfCategory} from "../../../helper/QuizHelper";
import {NavigationProp} from "@react-navigation/native";
import BlueButton from "../../../components/buttons/BlueButton";

interface Props {
    navigation: NavigationProp<any>;
}
export default function OnlinePlayQuiz({navigation}: Props) {
    const [codeQuiz, setCodeQuiz] = React.useState("");
    const [error, setError] = React.useState<string>("");
    const {getRunsInfo} = useQuizService();

    const checkRoomExist = async () : Promise<boolean> => {
        const runFetched = await getRunsInfo(codeQuiz);
        if(runFetched instanceof HttpError) {
            return false;
        }
        return true;
    }

    const joinLobby = async ()  => {
        const response = await checkRoomExist()
        if(!response) {
            setError("The room does not exist");
            return;
        }
        setError("");
        navigation.navigate("Lobby", {
            quizId: null,
            roomId: codeQuiz,
            nbPlayers: 10,
            isHost: false,
            questionCount: 10
        });
    };

    return (
        <View style={styles.container}>
            <View style={styles.contentContainer}>
                <View style={styles.fieldContainer}>
                    {error ? <Text style={styles.errorText}>{error}</Text> : null}
                    <InputPlayQuiz placeholder={"Enter room ID"} setText={setCodeQuiz} noTitle={true} />
                </View>
                <View style={styles.buttonPlayContainer}>
                    <BlueButton onPress={joinLobby} text={"JOIN"} isDisabled={codeQuiz==="" || error!==""}/>
                </View>
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: "flex",
        width: "100%",
        height: "75%",
        justifyContent: "space-between",
    },
    contentContainer: {
        flex: 1, // Prend toute la hauteur disponible
        flexDirection: "column",
        justifyContent: "space-between",
    },
    fieldContainer: {
        width: "100%",
        flexDirection: "column",
        justifyContent: "space-between",
        marginTop: 20,
        gap: 20,
    },
    buttonPlayContainer: {
        alignItems: "center",
        paddingVertical: 20,
    },
    errorText: {
        color: "red",
        fontSize: 16,
        marginBottom: 5,
        textAlign: "left", // Aligne le texte à gauche
    },
});
