import { View, Image, Text, StyleSheet } from "react-native";
import DefaultButton from "../../../components/buttons/DefaultButton";
import { NavigationProp, RouteProp } from "@react-navigation/native";
import {Quiz} from "../../../models/Quiz";
import {useQuizService} from "../../../services/QuizService";
import HttpError from "../../../services/HttpError";
import UserScore from "../../../components/PlayingQuiz/EndQuiz/UserScore";
import EndQuizListPlayer from "../../../components/PlayingQuiz/EndQuiz/EndQuizListPlayer";
import {UserEndQuiz} from "../../../models/UserEndQuiz";



interface Props {
    navigation: NavigationProp<any>;
    users: UserEndQuiz[]
    questionCount: number
}

export default function EndQuizMultiChild({ navigation, users, questionCount}: Props) {


    const handleBackToMenu = () => {
        navigation.navigate('TabNavigator');
    };

    return (
        <View style={styles.container}>
            <View style={styles.containerHeader}>
                <Image source={require('../../../assets/TitleApp.png')}/>
            </View>
            <View style={styles.containerBody}>
                <Image
                    source={require('../../../assets/stars.png')} // URL de l'avatar ou placeholder
                    style={styles.stars}
                />
                <View style={styles.usersContainer}>
                    { users[1] && (<UserScore user={users[1]} score={10} maxScore={questionCount} isFirst={false}/>)}
                    <UserScore user={users[0]} score={10} maxScore={questionCount} isFirst={true}/>
                    { users[2] &&(<UserScore user={users[2]} score={10} maxScore={questionCount} isFirst={false}/>)}
                </View>
                <EndQuizListPlayer users={users} maxScore={questionCount}/>

                {/*<DefaultButton text="RESTART" handleButtonPressed={handleRestartPress} buttonStyle={styles.whiteButton} buttonText={styles.whiteButtonText}></DefaultButton>*/}
                <DefaultButton text="BACK TO MENU" handleButtonPressed={handleBackToMenu} buttonStyle={styles.blueButton} buttonText={styles.blueButtonText}></DefaultButton>
            </View>
        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        height: '100%',
        width: '100%',
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        justifyContent: 'space-around'
    },
    usersContainer: {
        display: 'flex',
        width: '100%',
        flexDirection: 'row',
        alignItems: 'center',
        justifyContent: 'space-around',
    },
    containerHeader: {
        height: '10%',
        width: '100%',
        alignItems: 'center',
    },
    containerBody: {
        height: '80%',
        width: '90%',
        display: 'flex',
        flexDirection: 'column',
        alignItems: 'center',
        justifyContent: 'space-around',
        backgroundColor: '#F3F3F3',
        borderRadius: 40,
        padding: '5%',
        shadowColor: "#000",
        shadowOffset: {
            width: 0,
            height: 2,
        },
        shadowOpacity: 0.25,
        shadowRadius: 3.84,
        elevation: 5,
    },
    TextBodyTitle: {
        textAlign: 'center',
        fontSize: 24,
        fontWeight: 'bold',
    },
    TextBody: {
        textAlign: 'center',
        fontSize: 22,
        fontWeight: 'bold',
    },
    whiteButton: {
        height: '12%',
        width: '80%',
        backgroundColor: '#FFFFFF',
        borderColor: '#2B73FE',
        borderWidth: 4,
        borderRadius: 10,
        padding: 0
    },
    whiteButtonText: {
        fontSize: 24,
        fontWeight: 'bold',
        color: '#2B73FE',
    },
    blueButton: {
        height: '12%',
        width: '80%',
        backgroundColor: '#2B73FE',
        borderRadius: 10,
        padding: 0
    },
    blueButtonText: {
        fontSize: 24,
        fontWeight: 'bold',
        color: '#FFFFFF',
    },
    stars: {
        resizeMode: "cover",
    },
});