import PlayingQuizHeader from "./PlayingQuizHeader";
import React, {useEffect, useState} from "react";
import TemplateDuo from "../../templates/TemplateDuo";
import {NavigationProp, RouteProp} from "@react-navigation/native";
import {QuizInformations} from "../../models/QuizInformations";
import {useQuizService} from "../../services/QuizService";
import HttpError from "../../services/HttpError";
import {Question} from "../../models/Question";
import PlayingQuizBody from "./PlayingQuizBody";
import { shuffleAnswersOfQuiz } from "../../helper/QuizHelper";


type RoutePropsType = {
    PlayingQuiz: {
        runId: string;
        quizId: string;
    };
};

interface Props {
    route: RouteProp<RoutePropsType, "PlayingQuiz">;
    navigation: NavigationProp<any>;
}

export default function PlayingQuiz({route, navigation}:Props) {
    const {runId, quizId} = route.params;
    const { getQuizInformations, getActualQuestionOfAQuiz } = useQuizService();
    const [quizInformations, setQuizInformations] = useState<QuizInformations | undefined>(undefined);
    const [actualQuestion, setActualQuestion] = useState<Question | undefined>(undefined);
    const [score, setScore] = useState(0);

    const fetchQuizInformations = async () => {
        const quizInformationsFetched = await getQuizInformations(quizId);
        if (HttpError.isHttpError(quizInformationsFetched)) {
            return;
        }
               
        setQuizInformations(quizInformationsFetched);
    }

    const fetchActualQuestion = async () => {
        const actualQuestionFetched = await getActualQuestionOfAQuiz(runId);
        if (HttpError.isHttpError(actualQuestionFetched)) {
            return;
        }
        const actualQuestionFetchedShuffle = shuffleAnswersOfQuiz(actualQuestionFetched);
        setActualQuestion(actualQuestionFetchedShuffle);
    }

    useEffect(() => {
        fetchQuizInformations();
    }, []);

    useEffect(() => {
        fetchActualQuestion();
    }, [quizId]);

    return (
        <TemplateDuo
            childrenHeader={<PlayingQuizHeader quizInformations={quizInformations} runId={runId} actualQuestion={actualQuestion} score={score} navigation={navigation}></PlayingQuizHeader>}
            childrenBody={<PlayingQuizBody score={score} quizInformations={quizInformations} runId={runId} actualQuestion={actualQuestion} fetchActualQuestion={fetchActualQuestion} setScore={setScore} navigation={navigation}></PlayingQuizBody>}
        />
    );
}