import {Keyboard, StyleSheet, Text, TouchableOpacity, TouchableWithoutFeedback, View} from "react-native";
import ProfilSelectMode from "../ProfilSelectMode";
import React, {useState} from "react";
import {ProfilSelectModeType} from "../../../models/SelectModeType";
import {NavigationProp} from "@react-navigation/native";
import ConnectionLogin from "./ConnectionLogin";
import ConnectionSignup from "./ConnectionSignup";

interface Props {
    title: string;
    navigation: NavigationProp<any>;
}

export default function Connection({title, navigation}: Props) {
    const [mode, setMode] = useState<ProfilSelectModeType>("login");

    return (
        <TouchableWithoutFeedback onPress={Keyboard.dismiss}>
            <View style={styles.container}>
                <Text style={styles.title}>{title}</Text>
                <View style={styles.containerModal}>
                    <ProfilSelectMode mode={mode} setMode={setMode} />
                    {mode === "login" ? (
                        <ConnectionLogin navigation={navigation} />
                    ) : (
                        <ConnectionSignup navigation={navigation} />
                    )}
                </View>
            </View>
        </TouchableWithoutFeedback>
    );
}

const styles = StyleSheet.create({
    container: {
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
        height: "100%",
        width: "100%",
    },
    title: {
        fontSize: 40,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
        alignSelf: "center", // Centre uniquement le titre
    },
    backgroundShadow: {
        height: "100%",
        width: "100%",
        backgroundColor: "#000000",
        opacity: 0.55,
        position: "absolute",
    },
    containerModal: {
        height: 600,
        width: "90%",
        backgroundColor: "#D9D9D9",
        borderRadius: 40,
        padding: '7%',
    },
    closeButton: {
        position: "absolute",
        top: '1%',
        right: '1%',
        zIndex: 1,
        backgroundColor: "white",
        borderRadius: 10,
        margin: '5%',
    },
});