import { TextInput, View, StyleSheet, Text } from "react-native";
import InputPlayQuiz from "../../../components/PlayQuiz/InputPlayQuiz";
import React, { useState } from "react";
import {useUserService} from "../../../services/UserService";
import HttpError from "../../../services/HttpError";
import {NavigationProp} from "@react-navigation/native";
import BlueButton from "../../../components/buttons/BlueButton";

interface Props {
    navigation: NavigationProp<any>;
}
export default function ConnectionLogin({navigation}: Props) {
    const [email, setEmail] = useState("");
    const [password, setPassword] = useState("");
    const [error, setError] = useState<string | null>(null);
    const { loginUser } = useUserService();

    const handleSubmitPressed = async () => {
        if (email === "" || password === "") {
            setError("Please fill in all fields");
            return;
        }
        const login = await loginUser(email, password);
        if(login instanceof HttpError){
            setError(login.message);
            return;
        }
        setError(null);
        navigation.reset({
            routes: [{name: "TabNavigator"}],
        });
    };

    return (
        <View style={styles.container}>
            {error && <Text style={styles.errorText}>{error}</Text>}
            <View style={styles.containerForm}>
                <InputPlayQuiz placeholder="EMAIL..." setText={setEmail} noTitle={true} />
                <InputPlayQuiz placeholder="PASSWORD..." setText={setPassword} noTitle={true} isSecure={true}/>
            </View>
            <BlueButton text="LOGIN" onPress={handleSubmitPressed} buttonStyle={styles.SubmitButton} isDisabled={false}/>
        </View>
    );
}

const styles = StyleSheet.create({
    containerForm: {
        height: 'auto',
        width: '100%',
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'flex-start',
        rowGap: '7%',
        marginTop: "3%",
        marginBottom: "auto", // Espacement entre le texte d'erreur et les inputs
    },
    container:{
        height: 475,
        paddingTop: '5%',
        display: 'flex',
        justifyContent: 'space-between'
    },
    textInput: {
        height: '20%',
        width: '100%',
        backgroundColor: '#FFFFFF',
        borderWidth: 4,
        borderColor: '#1fa9ff',
        borderRadius: 10,
        color: '#DFDFDF',
        fontWeight: 'bold',
    },
    SubmitButton: {
        height: '15%',
        width: '100%',
        backgroundColor: '#2b73fe',
        borderRadius: 10,
    },
    errorText: {
        color: 'red',
        fontSize: 16,
        textAlign: 'center', // Centrer le message d'erreur
    },
});
