import {TextInput, View, StyleSheet, Text} from "react-native";
import DefaultButton from "../../../components/buttons/DefaultButton";
import InputPlayQuiz from "../../../components/PlayQuiz/InputPlayQuiz";
import React, {useState} from "react";
import {useUserService} from "../../../services/UserService";
import HttpError from "../../../services/HttpError";
import {NavigationProp} from "@react-navigation/native";
import BlueButton from "../../../components/buttons/BlueButton";

interface Props {
    navigation: NavigationProp<any>;
}
export default function ConnectionSignup({navigation}: Props) {

    const [email, setEmail] = useState("");
    const [username, setUsername] = useState("");
    const [password, setPassword] = useState("");
    const [repeatPassword, setRepeatPassword] = useState("");
    const [error, setError] = useState<string | null>(null);
    const { registerUser } = useUserService();

    const handleSubmitPressed = async () => {
        if (email === "" || username === "" || password === "" || repeatPassword === "") {
            setError("Please fill in all fields");
            return;
        }
        if(password.length < 8){
            setError("Password must be at least 8 characters long");
            return;
        }
        if(password !== repeatPassword){
            setError("Passwords do not match");
            return;
        }
        const register = await registerUser(username, password, email);
        if(register instanceof HttpError){
            setError(register.message);
            return;
        }
        setError(null);
        navigation.reset({
            routes: [{name: "TabNavigator"}],
        });
    }

    return (
        <View style={styles.container}>
            {error && <Text style={styles.errorText}>{error}</Text>}
            <View style={styles.containerForm}>
                <InputPlayQuiz placeholder="USERNAME..." setText={setUsername} noTitle={true}/>
                <InputPlayQuiz placeholder="EMAIL..." setText={setEmail} noTitle={true}/>
                <InputPlayQuiz placeholder="PASSWORD..." setText={setPassword} noTitle={true} isSecure={true}/>
                <InputPlayQuiz placeholder="REPEAT PASSWORD..." setText={setRepeatPassword} noTitle={true} isSecure={true}/>
            </View>
            <BlueButton text="SIGNUP" onPress={handleSubmitPressed} buttonStyle={styles.SubmitButton} isDisabled={false}/>
        </View>
    )
}

const styles = StyleSheet.create({
    containerForm: {
        height: 'auto',
        width: '100%',
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'flex-start',
        rowGap: '5%',
        marginTop: "3%",
    },
    container:{
        height: 475,
        paddingTop: '5%',
        display: 'flex',
        justifyContent: 'space-between'
    },
    textInput: {
        height: '20%',
        width: '100%',
        backgroundColor: '#FFFFFF',
        borderWidth: 4,
        borderColor: '#1fa9ff',
        borderRadius: 10,
        color: '#DFDFDF',
        fontWeight: 'bold'
    },
    SubmitButton: {
        height: '15%',
        width: '100%',
        backgroundColor: '#2b73fe',
        borderRadius: 10,
    },
    SubmitText: {
        fontSize: 20,
        fontWeight: 'bold',
        color: '#FFFFFF',
    },
    errorText: {
        color: 'red',
        fontSize: 16,
        marginBottom: 10, // Espacement entre le texte d'erreur et les inputs
        textAlign: 'center', // Centrer le message d'erreur
    },
});