import { NavigationProp } from "@react-navigation/native";
import { View, StyleSheet, Image, Text, TouchableOpacity } from "react-native";
import React, { useEffect, useState } from "react";
import { ProfilSelectModeType } from "../../models/SelectModeType";
import { useUserService } from "../../services/UserService";
import HttpError from "../../services/HttpError";
import Icon from "react-native-vector-icons/MaterialIcons";
import {User, UserConnectionState} from "../../models/User";
import StatsOfUsers from "../../components/Profil/StatsOfUsers";
import LoadingIndicator from "../../components/loading/LoadingIndicator";
import Connection from "./Connection/Connection";

interface Props {
    navigation: NavigationProp<any>;
}



export default function ProfilChild({ navigation }: Props) {
    const [isLogged, setIsLogged] = useState(false);
    const [modalVisible, setModalVisible] = useState(false);
    const [mode, setMode] = useState<ProfilSelectModeType>("login");
    const [user, setUser] = useState<User | undefined>(undefined);
    const [userConnectionState, setUserConnectionState] = useState(UserConnectionState.LOADING);
    const { getInformationsUser, logoutUser } = useUserService();


    const getUser = async () => {
        setUserConnectionState(UserConnectionState.LOADING);
        const user = await getInformationsUser();
        if(user instanceof HttpError){
            setUser(undefined);
            setUserConnectionState(UserConnectionState.NOT_CONNECTED);
            return;
        }
        setUserConnectionState(UserConnectionState.CONNECTED);
        setUser(user);
    }

    useEffect(() => {
        getUser();
    }, []);

    // Pour s'adapter quand l'état de connexion change
    useEffect(() => {
        getUser();
    }, [isLogged]);

    const handleLogout = async () => {
        const result = await logoutUser();
        if (!(result instanceof HttpError)) {
            setUser(undefined); // Réinitialise l'utilisateur après la déconnexion
        }
        navigation.reset({
            routes: [{name: "TabNavigator"}],
        });
    };

    return (
        <View style={styles.containerGlobal}>
            {userConnectionState === UserConnectionState.LOADING && (
                <LoadingIndicator/>
            )}
            {userConnectionState === UserConnectionState.CONNECTED && (
                <>
            <View style={styles.containerPlayerInfos}>
                <Image source={require('../../assets/TitleApp.png')} style={styles.titleImage} />
                <Image source={require('../../assets/ProfilBaseImage.png')} style={styles.profilImage} />
                <Text style={styles.pseudoText}>{user ? user.username : "?"}</Text>
            </View>
            <StatsOfUsers user={user}/>
            <TouchableOpacity style={styles.logoutButton} onPress={handleLogout}>
                <Icon name="logout" size={40} color="#FF0000" />
            </TouchableOpacity>
            </>
        )}
            {userConnectionState === UserConnectionState.NOT_CONNECTED && (
                <Connection title={"Profil"} navigation={navigation}  />
                )}
        </View>
    );
}

const styles = StyleSheet.create({
    containerGlobal: {
        display: "flex",
        width: "100%",
        height: "100%",
        justifyContent: "flex-start",
        alignItems: "center",
    },
    containerPlayerInfos: {
        width: "100%",
        display: "flex",
        alignItems: "center",
    },
    title: {
        fontSize: 40,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
        alignSelf: "center", // Centre uniquement le titre
    },
    titleImage: {
        width: "45%",
        resizeMode: "contain",
    },
    profilImage: {
        width: "45%",
        aspectRatio: 1,
    },
    pseudoText: {
        fontSize: 35,
        fontWeight: "bold",
        color: "#00B3F4",
    },
    containerPlayerStats: {
        width: "100%",
        padding: "5%",
    },
    statsText: {
        fontSize: 17,
        fontWeight: "bold",
    },
    logoutButton: {
        position: "absolute",
        bottom: 20,
        right: 20,
        backgroundColor: "#FFF",
        borderRadius: 50,
        padding: 10,
        elevation: 5, // Ombre pour Android
        shadowColor: "#000", // Ombre pour iOS
        shadowOffset: { width: 0, height: 2 },
        shadowOpacity: 0.2,
        shadowRadius: 2,
    },
});
