import { View, Text, StyleSheet, TouchableOpacity } from "react-native";
import { ProfilSelectModeType } from "../../models/SelectModeType";

interface Props {
    mode: ProfilSelectModeType;
    setMode: (mode: ProfilSelectModeType) => void;
}

export default function ProfilSelectMode({ mode, setMode }: Props) {
    return (
        <View style={styles.container}>
            <View style={styles.buttonContainer}>
                <TouchableOpacity onPress={() => setMode("login")} style={{marginLeft: '10%'}}>
                    <Text style={[styles.text, mode === "login" && styles.activeText]}>LOGIN</Text>
                </TouchableOpacity>
                <View style={[styles.bar, mode === "login" ? styles.activeBar : styles.inactiveBar]} />
            </View>

            <View style={styles.buttonContainer}>
                <TouchableOpacity onPress={() => setMode("signup")} style={{marginRight: '10%'}}>
                    <Text style={[styles.text, mode === "signup" && styles.activeText]}>SIGNUP</Text>
                </TouchableOpacity>
                <View style={[styles.bar, mode === "signup" ? styles.activeBar : styles.inactiveBar]} />
            </View>

        </View>
    );
}

const styles = StyleSheet.create({
    container: {
        display: 'flex',
        width: '100%',
        height: '15%',
        flexDirection: 'row',
        backgroundColor: '#f3f3f3',
        borderRadius: 10,
        justifyContent: 'space-around',
        alignItems: 'center',
        // Ombre pour Android
        elevation: 5,
        // Ombre pour iOS
        shadowColor: '#000',
        shadowOffset: { width: 0, height: 4 }, // Décalage de l'ombre en bas
        shadowOpacity: 0.25, // Opacité de l'ombre
        shadowRadius: 3.84, // Flou de l'ombre
    },
    buttonContainer: {
        display: 'flex',
        flexDirection: 'column',
        width: '40%',
        alignItems: 'center',
        gap: "5%",
    },
    text: {
        fontSize: 25,
        color: '#bebebe',
    },
    activeText: {
        color: '#2b73fe',
    },
    bar: {
        width: '100%',
        height: '4%',
        marginTop: '4%',
        borderRadius: 10,
    },
    activeBar: {
        backgroundColor: '#2b73fe', // Couleur pour le bouton actif
    },
    inactiveBar: {
        backgroundColor: '#bebebe', // Couleur grise pour les boutons inactifs
    },
});
