import axios from "axios";
import {QuestionResponse} from "../models/Response/QuestionResponse";
import HttpError from "./HttpError";

export const useMultiService = () => {
    const url = "https://klebert-host.com:33036"

        const createParty = async (quizId: string) : Promise<string | HttpError> => {
        const requestBody = {
            quizId: quizId,
        };

        try {
            const response = await axios.post(`${url}/party`, requestBody, {
                withCredentials: true,
            });
            return response.data.id;
        } catch (error: any) {

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    }

    const generateRun = async () : Promise<string | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/generateRun`, {
                withCredentials: true,
            });
            return response.data.runId;
        } catch (error: any) {
            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const revealAnswer = async () : Promise<boolean | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/revealAnswer`, {
                withCredentials: true,
            });
            return true;
        } catch (error: any) {
            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const answerQuestion = async (questionId: number, answerId: number) : Promise<boolean | HttpError> => {
        const requestBody = {
            questionId: questionId,
            answerId: answerId,
        };

        try {
            const response = await axios.post(`${url}/party/answer`, requestBody,{
                withCredentials: true,
            });
            return true;
        } catch (error: any) {

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const nextQuestion = async () : Promise<boolean | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/nextQuestion`, {
                withCredentials: true,
            });
            return true;
        } catch (error: any) {

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const startParty = async () : Promise<boolean | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/start`, {
                withCredentials: true,
            });
            return true;
        } catch (error: any) {

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    const getScore = async () : Promise<number | HttpError> => {
        try {
            const response = await axios.get(`${url}/party/score`, {
                withCredentials: true,
            });
            return response.data.score;
        } catch (error: any) {

            if (error.response) {
                return new HttpError(error.response.status, error.response.data?.message || "HTTP error");
            } else {
                return new HttpError(500, "Unexpected error: " + error.message);
            }
        }
    };

    return {
        createParty: createParty,
        generateRun: generateRun,
        revealAnswer: revealAnswer,
        nextQuestion: nextQuestion,
        answerQuestion: answerQuestion,
        startParty: startParty,
        getScore: getScore
    }

}