import {ImageBackground, Text, View, StyleSheet, SafeAreaView} from "react-native";
import HeaderNavigation from "../components/navigation/HeaderNavigation";
import {NavigationProp} from "@react-navigation/native";

interface Props{
    children: React.ReactNode
    navigation: NavigationProp<any>;
    headerNavigation: boolean;
    buttonGoBack: boolean
}

/**
 * TemplateMenu : Template du menu principal
 * @param children - Contenu du menu
 * @param navigation - Navigation
 * @param headerNavigation - Si le menu est en haut de page
 * @param buttonGoBack - boolean qui dit si le bouton de retour doit être affiché
 */
export default function TemplateMenu({children, navigation, headerNavigation, buttonGoBack}: Props) {
    return (
        <View style={styles.container}>

            <ImageBackground source={require('../assets/MenuBackground.png')} style={styles.image}>
                <SafeAreaView>
                    {headerNavigation && <HeaderNavigation navigation={navigation} buttonGoBack={buttonGoBack}/>}
                <View style={styles.container}>
                    {children}
                </View>
                </SafeAreaView>
            </ImageBackground>

        </View>
    );
}


const styles = StyleSheet.create({
    container: {
        display: 'flex',
        width: '100%',
        height: '100%',
    },
    image: {
        height: '100%',
        width: '100%',
    }
});