import React from "react";
import {View, Text, StyleSheet} from "react-native";
import TemplateMenu from "./TemplateMenu";
import {NavigationProp} from "@react-navigation/native";
import RunStartedList from "../components/PlayQuiz/RunStartedList";
import {RunsInformationsAllRuns} from "../models/RunsInformationsAllRuns";


/**
 * TemplateQuizList : Un composant principal pour afficher une liste de quiz.
 * Il inclut un menu, un titre, un champ d'entrée pour les recherches et une liste de quiz.
 *
 * @param navigation - L'objet de navigation pour naviguer entre les écrans
 * @param title - Le titre affiché en haut de la liste
 * @param setTextInInput - Fonction pour gérer les modifications dans le champ d'entrée
 * @param quizList - La liste des quiz à afficher
 * @param buttonGoBack - boolean qui dit si le bouton de retour doit être affiché
 */

interface Props {
    navigation: NavigationProp<any>
    title: string
    setTextInInput: (text: string) => void
    runList: RunsInformationsAllRuns[] | undefined
    buttonGoBack: boolean
    isLoadingData: boolean
    nextPage?: () => void;
    onRunPressed:(runInfo: RunsInformationsAllRuns) => void;
}

export default function TemplateRunList({navigation, title, setTextInInput, runList, buttonGoBack, isLoadingData, onRunPressed }: Props) {
    return (
        <TemplateMenu navigation={navigation} headerNavigation={true} buttonGoBack={buttonGoBack}>
            <View style={styles.globalContainer}>
                <Text style={styles.title}>{title}</Text>
                <View style={styles.contentContainer}>
                    <RunStartedList runList={runList} isLoadingData={isLoadingData} onRunPressed={onRunPressed}/>
                </View>
            </View>
        </TemplateMenu>
    );
}

const styles = StyleSheet.create({
    globalContainer: {
        display: "flex",
        height: "100%",
        width: "100%",
        paddingHorizontal: "3%", // Ajoute une marge de 5% à gauche et à droite
        alignItems: "center", // Centre tous les enfants horizontalement
    },
    title: {
        fontSize: 40,
        fontWeight: "bold",
        color: "#00b3f4",
        marginBottom: 10,
        alignSelf: "center", // Centre uniquement le titre
    },
    contentContainer: {
        display: "flex",
        flexDirection: "column",
        width: "100%", // Utilise tout l'espace restant à l'intérieur de `globalContainer`
        height: "75%",
        alignItems: "center", // Centre tous les enfants horizontalement
        gap: "2%",
    },
});
